# FormatForDYNA
<p>Excel tool that automates formatting of LS-DYNA array data for the following input cards:</p>
    * LCID (2 columns)
    * NODE (10 columns)
    * ELEMENT_SET (10 columns)
    
<p>Developer: @Kevin.Stanton</p>

## Instructions: 
1. Paste unformatted data as values into cell A2
2. Select the data type from the dropdown in cell N1
3. Click "Run"
4. Copy the result and paste below the front matter of the appropriate LS-DYNA input card

## Prerequisites:
* Microsoft Excel (macros-enabled)